@@ -1,35 +1,24 @@
-import os
-import sys
-
-import pymysql
-from dotenv import load_dotenv
+from python_sdk_remote.mini_logger import MiniLogger
 
+from .Connector import get_connection
 from .MessageSeverity import MessageSeverity
 from .SendToLogzIo import SendTOLogzIo
 
-load_dotenv()
-
-FIELDS_LIST = None
 COMPUTER_LANGUAGE = "Python"
 COMPONENT_ID = 102
 COMPONENT_NAME = 'Logger Python'
 Logzio_handler = SendTOLogzIo()
 
-
-def get_connection() -> pymysql.connections.Connection:
-    return pymysql.connect(
-        host=os.getenv('RDS_HOSTNAME'),
-        user=os.getenv('RDS_USERNAME'),
-        password=os.getenv('RDS_PASSWORD'),
-
-    )
+cache = []
 
 
 class Fields:
     @staticmethod
-    def getFieldsSingelton():
-        if FIELDS_LIST is not None:
-            return
+    def get_logger_table_fields():
+        """Returns the list of columns in the logger table"""
+        global cache
+        if cache:
+            return cache
         sql_query = f"DESCRIBE logger.logger_table"
         try:
             object1 = {
@@ -45,12 +34,15 @@ class Fields:
                 'message': "get_logger_table_fields activated",
             }
             Logzio_handler.send_to_logzio(object1)
-            con = get_connection()
+            con = get_connection(schema_name="logger")
             cursor = con.cursor()
             cursor.execute(sql_query)
             columns_info = cursor.fetchall()
-            return [column[0] for column in columns_info]
-        except Exception as e:
-            print("logger-local-python-package LoggerService.py sql(self) Exception caught SQL=" +
-                  sql_query + " Exception=" + str(e), file=sys.stderr)
+            columns = [column[0] for column in columns_info]
+            cache = columns
+            return columns
+
+        except Exception as exception:
+            MiniLogger.exception("logger-local-python-package LoggerService.py sql(self) Exception caught SQL=" +
+                                 sql_query, exception)
             return
